import unittest

from pyreutil.pyreutil import *

class TestReUtil(unittest.TestCase):
    
    def test_search_and_replace(self):
        regex_with_groups = "\[([\[]?[^\[^\]]+[\]]?)]\((http[s]?://[^\)]+)\)"
        sample_text = "In 1913,  [Ernst Zermelo](https://en.wikipedia.org/wiki/Ernst_Zermelo)  published *Über eine Anwendung der Mengenlehre auf die Theorie des Schachspiels* (*On an Application of Set Theory to the Theory of the Game of Chess*), which proved that the optimal chess strategy is  [strictly determined](https://en.wikipedia.org/wiki/Strictly_determined_game) . This paved the way for more general theorems. [[4]](https://en.wikipedia.org/wiki/Game_theory#cite_note-4) "
        
        self.assertRaises(TypeError, ReUtil().search_and_replace, regex=regex_with_groups, text=sample_text, replace="link", group=1)
        self.assertRaises(TypeError, ReUtil().search_and_replace, regex=regex_with_groups, text=sample_text)
        
        expected1 = "In 1913,  Ernst Zermelo  published *Über eine Anwendung der Mengenlehre auf die Theorie des Schachspiels* (*On an Application of Set Theory to the Theory of the Game of Chess*), which proved that the optimal chess strategy is  strictly determined . This paved the way for more general theorems. [4] "
        expected2 = "In 1913,  [link]  published *Über eine Anwendung der Mengenlehre auf die Theorie des Schachspiels* (*On an Application of Set Theory to the Theory of the Game of Chess*), which proved that the optimal chess strategy is  [link] . This paved the way for more general theorems. [link] "
        
        result1 = ReUtil().search_and_replace(regex_with_groups, sample_text, group=1)
        result2 = ReUtil().search_and_replace(regex_with_groups, sample_text, replace="[link]")
        self.assertEquals(expected1, result1)
        self.assertEquals(expected2, result2)
   
if __name__ == "__main__":
    unittest.main()
        


import unittest

from pyreutil.utils import *

class TestUtils(unittest.TestCase):
    
    def test_get_subdir_and_file_from_dir(self):
        original_dir = 'home/user/dir1'
        fullpath = 'home/user/dir1/dir2/dir3/file.txt'
        subdirs, filename = get_subdir_and_file_from_dir(fullpath, original_dir)
        self.assertEqual(subdirs, ['dir2', 'dir3'])
        self.assertEqual(filename, 'file.txt')


from setuptools import setup

with open("README.md",'r') as fh:
    long_description = fh.read()

setup(
    name='pyreutil',
    version=open('VERSION','r').read().strip(),
    author='Michelle Sun',
    author_email='michelle.sun032@icloud.com',
    url='https://github.com/michsun/pyreutil',
    description='Pyreutil is a command line utility to bulk edit plain text files or filenames using regex.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 4 - Beta",
		"Programming Language :: Python :: 3",
		"Programming Language :: Python :: 3.8",
		"Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
    packages=['pyreutil'],
    install_requires=open('requirements.txt').read().splitlines(),
    entry_points= {
        'console_scripts': ['pyreutil = pyreutil.__main__:main']
    }
)